@@ -561,12 +561,6 @@ class frmStartWindow(QMainWindow):
         
     def ShowHelpWindow(self):
         HelpWindow.show()
-        #    cmd="dbus-send --system --type=method_call --dest=com.nokia.osso_browser /com/nokia/osso_browser/request com.nokia.osso_browser.load_url string:\"/opt/SleepAnalyser/Info.htm\""
-#        cmd="dbus-send --type=method_call --dest=com.nokia.osso_browser /com/nokia/osso_browser com.nokia.osso_browser.load_url string:\"/opt/SleepAnalyser/Info.htm\""
-#        ret=os.popen2(cmd) #get current mode
-
-
-
 
 
 
@@ -645,6 +639,7 @@ class frmRecordWindow(QMainWindow):
         QtCore.QObject.connect(self.ui.bZoomOut, QtCore.SIGNAL("clicked()"), self.ZoomOut)
         QtCore.QObject.connect(self.ui.bEditNote, QtCore.SIGNAL("clicked()"), self.EditNote)
         
+        QtCore.QObject.connect(self.ui.actionHelp, QtCore.SIGNAL("triggered()"), self.ShowHelpWindow)
         QtCore.QObject.connect(self.ui.actionAbout, QtCore.SIGNAL("triggered()"), self.About)
 
         #Add styles to buttons
@@ -819,7 +814,8 @@ class frmRecordWindow(QMainWindow):
         About(self)
 
 
-
+    def ShowHelpWindow(self):
+        HelpWindow.show()
 
 
 
@@ -861,6 +857,7 @@ class frmViewWindow(QMainWindow):
         QtCore.QObject.connect(self.ui.bOpenDate, QtCore.SIGNAL("clicked()"), self.OpenDate)
         QtCore.QObject.connect(self.ui.bStatistics, QtCore.SIGNAL("clicked()"), self.ShowRecordData)
 
+        QtCore.QObject.connect(self.ui.actionHelp, QtCore.SIGNAL("triggered()"), self.ShowHelpWindow)
         QtCore.QObject.connect(self.ui.actionAbout, QtCore.SIGNAL("triggered()"), self.About)
         QtCore.QObject.connect(self.ui.actionShowRecordData, QtCore.SIGNAL("triggered()"), self.ShowRecordData)
         QtCore.QObject.connect(self.ui.actionExport, QtCore.SIGNAL("triggered()"), self.Export)
@@ -1264,7 +1261,8 @@ class frmViewWindow(QMainWindow):
         AdditionalInfoWindow.UpdateScreen()
         AdditionalInfoWindow.show()
 
-
+    def ShowHelpWindow(self):
+        HelpWindow.show()
 
 
 
